[java-identity-provider COMMIT] in /trunk: idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameCanonicaliza...

noreply at shibboleth.net noreply at shibboleth.net
Tue Jan 28 05:18:23 EST 2014


Author: rdw
Date: Tue Jan 28 05:18:23 2014
New Revision: 5251

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=5251&view=rev
Log:
C14N: Remove redundant interface and collpase out distinguished Exception

Modified:
    trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameCanonicalization.java
    trunk/idp-saml-api/src/main/java/net/shibboleth/idp/saml/nameid/NameCanonicalizationException.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/AbstractTransientCanonicalization.java
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIDTransientCanonicalization.java

Modified: trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/AbstractTransientCanonicalization.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/AbstractTransientCanonicalization.java?rev=5251&r1=5250&r2=5251&view=diff
==============================================================================
--- trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIDTransientCanonicalization.java (original)
+++ trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIDTransientCanonicalization.java Tue Jan 28 05:18:23 2014
@@ -26,7 +26,6 @@
 import net.shibboleth.idp.authn.SubjectCanonicalizationException;

[... 16 lines stripped ...]


More information about the commits mailing list
--- trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/AbstractTransientCanonicalization.java (original)
+++ trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/AbstractTransientCanonicalization.java Tue Jan 28 05:18:23 2014
@@ -22,7 +22,7 @@
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
-import net.shibboleth.idp.saml.nameid.NameCanonicalizationException;
+import net.shibboleth.idp.authn.SubjectCanonicalizationException;
 import net.shibboleth.idp.saml.nameid.TransientIdParameters;
 import net.shibboleth.utilities.java.support.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.utilities.java.support.component.ComponentInitializationException;
@@ -37,7 +37,7 @@
 /**
  * TODO
  * An abstract action which contains the logic to do transient decoding matching (shared between SAML2
- * and SAML1)
+ * and SAML1).
  */
 public abstract class AbstractTransientCanonicalization extends AbstractSAMLNameCanonicalization {
 
@@ -72,37 +72,37 @@
      * @param transientId the transientID
      * @param requesterId the SP
      * @return the decoded entity.
      * @throws NameCanonicalizationException if a decode error occurrs.
      */
     protected String decode(@Nullable String transientId, @Nonnull String requesterId)
-            throws NameCanonicalizationException {
+            throws SubjectCanonicalizationException {
         Constraint.isNotNull(requesterId, "Supplied requested should be null");
 
         if (null == transientId) {
-            throw new NameCanonicalizationException(getLogPrefix() + " transient Identifier was null");
+            throw new SubjectCanonicalizationException(getLogPrefix() + " transient Identifier was null");
         }
 
         try {
             final StorageRecord record = idStore.read(TransientIdParameters.CONTEXT, transientId);
 
             if (null == record) {
-                throw new NameCanonicalizationException(getLogPrefix() + " Could not find transient Identifier");
+                throw new SubjectCanonicalizationException(getLogPrefix() + " Could not find transient Identifier");
             }
 
             if (record.getExpiration() < System.currentTimeMillis()) {
-                throw new NameCanonicalizationException(getLogPrefix() + " Transient identifier has expired");
+                throw new SubjectCanonicalizationException(getLogPrefix() + " Transient identifier has expired");
             }
 
             final TransientIdParameters param = new TransientIdParameters(record.getValue());
 
             if (!requesterId.equals(param.getAttributeRecipient())) {
-                throw new NameCanonicalizationException(getLogPrefix() + " Transient identifier was issued to "
+                throw new SubjectCanonicalizationException(getLogPrefix() + " Transient identifier was issued to "
                         + param.getAttributeRecipient() + " but is being used by " + requesterId);
             }
 
             return param.getPrincipal();
         } catch (IOException e) {
-            throw new NameCanonicalizationException(e);
+            throw new SubjectCanonicalizationException(e);
         }
     }
 
@@ -72,37 +72,37 @@
      * @param requesterId the SP
      * @return the decoded entity.
-     * @throws NameCanonicalizationException if a decode error occurrs.
+     * @throws SubjectCanonicalizationException if a decode error occurrs.
      */
     protected String decode(@Nullable String transientId, @Nonnull String requesterId)

Modified: trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIDTransientCanonicalization.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/nameid/NameIDTransientCanonicalization.java?rev=5251&r1=5250&r2=5251&view=diff
==============================================================================